@@ -4,7 +4,7 @@ from herre.wards.graphql import ParsedQuery
 CREATE_TABLE = ParsedQuery(
     """
 mutation CreateTable($sample: ID, $name: String, $tags: [String], $creator: String, $representation: ID, $experiment: ID){
-  createTable(sample: $sample, name: $name, rep: $rep, exp: $exp, tags: $tags, creator: $creator){
+  createTable(sample: $sample, name: $name, representation: $representation, experiment: $experiment, tags: $tags, creator: $creator){
     name
     id
     tags
